@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  * 
  * This program is part of the Exiv2 distribution.
  *
@@ -22,6 +22,7 @@
   File:      exivsimple.cpp
   Version:   $Rev$
   Author(s): Brad Schick <brad@robotbattle.com>
+             Christian Kuster <christian@kusti.ch>
   History:   12-Nov-04, brad: created
  */
 // *****************************************************************************
@@ -32,6 +33,7 @@
 #include "exif.hpp"
 #include "iptc.hpp"
 #include <cassert>
+#include <cstring>
 
 struct ImageWrapper
 {
@@ -150,6 +152,30 @@ EXIVSIMPLE_API int ImageData(HIMAGE img, BYTE *buffer, unsigned int size)
     return result;
 }
 
+EXIVSIMPLE_API void SetThumbnail(HIMAGE img, const BYTE *buffer, unsigned int size)
+{
+    ImageWrapper *imgWrap = (ImageWrapper*)img;
+    Exiv2::ExifData &exifData = imgWrap->image->exifData();
+    exifData.setJpegThumbnail(buffer, size);
+}
+
+EXIVSIMPLE_API unsigned int GetThumbnail(HIMAGE img, BYTE *buffer, unsigned int size)
+{
+    ImageWrapper *imgWrap = (ImageWrapper*)img;
+    Exiv2::ExifData &exifData = imgWrap->image->exifData();
+    Exiv2::Thumbnail::AutoPtr thumbnail;
+    thumbnail = exifData.getThumbnail();
+    if (thumbnail.get() == 0) {
+        return 0;
+    }
+    Exiv2::DataBuf buf = thumbnail->copy(exifData);
+    if (buf.size_ > (long)size) {
+        return unsigned int(-1);
+    }
+    memcpy(buffer, buf.pData_, buf.size_);
+    return buf.size_;
+}
+
 // This is weird because iptc and exif have not been "unified". Once
 // they are unified, this DLL should not have to know
 // about either... just generic images, keys, values, etc.
