@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -21,7 +21,7 @@
 /*!
   @file    basicio.hpp
   @brief   Simple binary IO abstraction
-  @version $Rev: 839 $
+  @version $Rev: 1039 $
   @author  Brad Schick (brad)
            <a href="mailto:brad@robotbattle.com">brad@robotbattle.com</a>
   @date    04-Dec-04, brad: created
@@ -175,7 +175,7 @@ namespace Exiv2 {
         /*!
           @brief Direct access to the IO data. For files, this is done by
                  mapping the file into the process's address space; for
-                 memory blocks, this allows direct access to the memory 
+                 memory blocks, this allows direct access to the memory
                  block.
 
           Todo: This is currently only for read access.
@@ -391,6 +391,9 @@ namespace Exiv2 {
           method returns. This method exists primarily to be used with
           the BasicIo::temporary() method.
 
+          @note If the caller doesn't have permissions to write to the file,
+              an exception is raised and \em src is deleted.
+
           @param src Reference to another BasicIo instance. The entire contents
               of src are transferred to this object. The \em src object is
               invalidated by the method.
@@ -618,8 +621,8 @@ namespace Exiv2 {
           @brief Allow direct access to the underlying data buffer. The buffer
                  is not protected against write access except for the const
                  specifier.
-          @note  The application must ensure that the memory pointed to by the 
-                 returned pointer remains valid and allocated as long as the 
+          @note  The application must ensure that the memory pointed to by the
+                 returned pointer remains valid and allocated as long as the
                  MemIo object is in scope.
          */
         virtual const byte* mmap() { return data_; }
