@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2005-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      crwimage.cpp
-  Version:   $Rev: 861 $
+  Version:   $Rev: 1046 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   28-Aug-05, ahu: created
 
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: crwimage.cpp 861 2006-08-15 14:40:34Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: crwimage.cpp 1046 2007-02-06 15:00:23Z ahuggel $")
 
 // Define DEBUG to output debug information to std::cerr, e.g, by calling make
 // like this: make DEFS=-DDEBUG crwimage.o
@@ -47,6 +47,7 @@ EXIV2_RCSID("@(#) $Id: crwimage.cpp 861 2006-08-15 14:40:34Z ahuggel $")
 #include "value.hpp"
 #include "tags.hpp"
 #include "canonmn.hpp"
+#include "i18n.h"                // NLS support.
 
 // + standard includes
 #include <iostream>
@@ -165,62 +166,15 @@ namespace Exiv2 {
         { 0xffff, 0xffff }
     };
 
-    CrwImage::CrwImage(BasicIo::AutoPtr io, bool create)
-        : Image(mdExif | mdComment), io_(io)
+    CrwImage::CrwImage(BasicIo::AutoPtr io, bool /*create*/)
+        : Image(ImageType::crw, mdExif | mdComment, io)
     {
-        if (create) {
-            IoCloser closer(*io_);
-            io_->open();
-        }
     } // CrwImage::CrwImage
 
-    bool CrwImage::good() const
-    {
-        if (io_->open() != 0) return false;
-        IoCloser closer(*io_);
-        return isThisType(*io_, false);
-    }
-
-    void CrwImage::clearMetadata()
-    {
-        clearExifData();
-        clearComment();
-    }
-
-    void CrwImage::setMetadata(const Image& image)
-    {
-        setExifData(image.exifData());
-        setComment(image.comment());
-    }
-
-    void CrwImage::clearExifData()
-    {
-        exifData_.clear();
-    }
-
-    void CrwImage::setExifData(const ExifData& exifData)
-    {
-        exifData_ = exifData;
-    }
-
-    void CrwImage::clearIptcData()
-    {
-        // not supported
-    }
-
     void CrwImage::setIptcData(const IptcData& /*iptcData*/)
     {
         // not supported
-    }
-
-    void CrwImage::clearComment()
-    {
-        comment_.erase();
-    }
-
-    void CrwImage::setComment(const std::string& comment)
-    {
-        comment_ = comment;
+        throw(Error(32, "IPTC metadata", "CRW"));
     }
 
     void CrwImage::readMetadata()
@@ -233,7 +187,7 @@ namespace Exiv2 {
         }
         IoCloser closer(*io_);
         // Ensure that this is the correct image type
-        if (!isThisType(*io_, false)) {
+        if (!isCrwType(*io_, false)) {
             if (io_->error() || io_->eof()) throw Error(14);
             throw Error(33);
         }
@@ -252,7 +206,7 @@ namespace Exiv2 {
         if (io_->open() == 0) {
             IoCloser closer(*io_);
             // Ensure that this is the correct image type
-            if (isThisType(*io_, false)) {
+            if (isCrwType(*io_, false)) {
                 // Read the image into a memory buffer
                 buf.alloc(io_->size());
                 io_->read(buf.pData_, buf.size_);
@@ -280,11 +234,6 @@ namespace Exiv2 {
 
     } // CrwImage::writeMetadata
 
-    bool CrwImage::isThisType(BasicIo& iIo, bool advance) const
-    {
-        return isCrwType(iIo, advance);
-    }
-
     void CrwParser::decode(CrwImage* pCrwImage, const byte* pData, uint32_t size)
     {
         assert(pCrwImage != 0);
@@ -638,7 +587,7 @@ namespace Exiv2 {
     void CiffHeader::print(std::ostream& os, const std::string& prefix) const
     {
         os << prefix
-           << "Header, offset = 0x" << std::setw(8) << std::setfill('0')
+           << _("Header, offset") << " = 0x" << std::setw(8) << std::setfill('0')
            << std::hex << std::right << offset_ << "\n";
         if (pRootDir_) pRootDir_->print(os, byteOrder_, prefix);
     } // CiffHeader::print
@@ -655,13 +604,13 @@ namespace Exiv2 {
                                 const std::string& prefix) const
     {
         os << prefix
-           << "tag = 0x" << std::setw(4) << std::setfill('0')
+           << _("tag") << " = 0x" << std::setw(4) << std::setfill('0')
            << std::hex << std::right << tagId()
-           << ", dir = 0x" << std::setw(4) << std::setfill('0')
+           << ", " << _("dir") << " = 0x" << std::setw(4) << std::setfill('0')
            << std::hex << std::right << dir()
-           << ", type = " << TypeInfo::typeName(typeId())
-           << ", size = " << std::dec << size_
-           << ", offset = " << offset_ << "\n";
+           << ", " << _("type") << " = " << TypeInfo::typeName(typeId())
+           << ", " << _("size") << " = " << std::dec << size_
+           << ", " << _("offset") << " = " << offset_ << "\n";
 
         Value::AutoPtr value;
         if (typeId() != directory) {
@@ -1342,7 +1291,6 @@ namespace Exiv2 {
 
     // *************************************************************************
     // free functions
-
     Image::AutoPtr newCrwInstance(BasicIo::AutoPtr io, bool create)
     {
         Image::AutoPtr image(new CrwImage(io, create));
