@@ -2,13 +2,13 @@
 /*!
   @file    doxygen.hpp
   @brief   Additional documentation, this file contains no source code
-  @version $Rev: 991 $
+  @version $Rev: 1062 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    07-Feb-04, ahu: created
  */
 /*!
-  @mainpage Exif and IPTC metadata library and tools v0.12
+  @mainpage Exif and IPTC metadata library and tools v0.13
 
   @section overview Exiv2 Overview
 
@@ -54,7 +54,7 @@
 
   - JPEG
   - <A HREF="crw-mapping.html">Canon CRW</A>
-  - TIFF and related RAW formats (Canon CR2, Nikon NEF, Pentax PEF, Sony SR2, Sony ARW, Adobe DNG, and Minolta MRW), read-only
+  - TIFF and related RAW formats (Adobe DNG, Canon CR2, Fujifilm RAF, Minolta MRW, Nikon NEF, Pentax PEF, Sony ARW and Sony SR2), read-only
   - PNG, read-only
 
   @section supp Support
@@ -82,26 +82,26 @@ bug tracking system</a>.</p>
 
   @verbatim $ svn checkout svn://dev.robotbattle.com/exiv2/trunk . @endverbatim
 
-  <p>To download the test data and test drivers for version 0.12 from
-  the repository, change to your local exiv2-0.12 directory and use the
+  <p>To download the test data and test drivers for version 0.13 from
+  the repository, change to your local exiv2-0.13 directory and use the
   following command:
   </p>
 
-  @verbatim $ svn export svn://dev.robotbattle.com/exiv2/tags/0.12/test @endverbatim
+  @verbatim $ svn export svn://dev.robotbattle.com/exiv2/tags/0.13/test @endverbatim
 
   <P>If you'd like to contribute code, please <A HREF="mailto:ahuggel@gmx.net">contact me</A>.
 
   @section license License
 
-  <P>Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net></P>
+  <P>Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net></P>
 
   <P>%Exiv2 is free software; you can redistribute it and/or modify it under the
   terms of the <a href="gpl-license.html">GNU General Public License</a> as
   published by the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.</P>
 
-  <P>Alternatively, %Exiv2 is also available with a commercial license, which 
-  allows it to be used in closed-source projects. 
+  <P>Alternatively, %Exiv2 is also available with a commercial license, which
+  allows it to be used in closed-source projects.
   <A HREF="mailto:ahuggel@gmx.net">Contact me</A> for more information.</P>
 
   <P>%Exiv2 is distributed in the hope that it will be useful, but WITHOUT ANY
