@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,21 +20,22 @@
  */
 /*
   File:      ifd.cpp
-  Version:   $Rev: 979 $
+  Version:   $Rev: 1039 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: ifd.cpp 979 2006-11-16 11:14:18Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: ifd.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
 
 // *****************************************************************************
 // included header files
 #include "ifd.hpp"
 #include "types.hpp"
 #include "error.hpp"
-#include "tags.hpp"                             // for ExifTags::ifdName
+#include "tags.hpp"              // for ExifTags::ifdName
+#include "i18n.h"                // NLS support.
 
 // + standard includes
 #include <iostream>
@@ -333,7 +334,7 @@ namespace Exiv2 {
             // Sanity check with an "unreasonably" large number
             if (n > 256) {
 #ifndef SUPPRESS_WARNINGS
-                std::cerr << "Error: " 
+                std::cerr << "Error: "
                           << "Directory " << ExifTags::ifdName(ifdId_) << " with "
                           << n << " entries considered invalid; not read.\n";
 #endif
@@ -379,7 +380,7 @@ namespace Exiv2 {
                     pNext_ = const_cast<byte*>(buf + o);
                 }
                 next_ = getULong(buf + o, byteOrder);
-                if (   static_cast<long>(next_) + shift < 0 
+                if (   static_cast<long>(next_) + shift < 0
                     || static_cast<long>(next_) + shift >= len) {
 #ifndef SUPPRESS_WARNINGS
                     std::cerr << "Warning: " << ExifTags::ifdName(ifdId_)
@@ -698,13 +699,13 @@ namespace Exiv2 {
     {
         if (entries_.size() == 0) return;
         // Print a header
-        os << prefix << "IFD Offset: 0x"
+        os << prefix << _("IFD Offset") << ": 0x"
            << std::setw(8) << std::setfill('0') << std::hex << std::right
            << offset_
-           << ",   IFD Entries: "
+           << ",   " << _("IFD Entries") << ": "
            << std::setfill(' ') << std::dec << std::right
            << static_cast<unsigned int>(entries_.size()) << "\n"
-           << prefix << "Entry     Tag  Format   (Bytes each)  Number  Offset\n"
+           << prefix << _("Entry     Tag  Format   (Bytes each)  Number  Offset\n")
            << prefix << "-----  ------  ---------------------  ------  -----------\n";
         // Print IFD entries
         const const_iterator b = entries_.begin();
@@ -736,14 +737,14 @@ namespace Exiv2 {
                << "\n";
         }
         if (hasNext_) {
-            os << prefix << "Next IFD: 0x"
+            os << prefix << _("Next IFD") << ": 0x"
                << std::setw(8) << std::setfill('0') << std::hex
                << std::right << next() << "\n";
         }
         // Print data of IFD entries
         for (i = b; i != e; ++i) {
             if (i->size() > 4) {
-                os << "Data of entry " << static_cast<int>(i - b) << ":\n";
+                os << _("Data of entry") << " " << static_cast<int>(i - b) << ":\n";
                 hexdump(os, i->data(), i->size(), offset_ + i->offset());
             }
         }
