@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,7 +20,7 @@
  */
 /*
   File:      jpgimage.cpp
-  Version:   $Rev: 994 $
+  Version:   $Rev: 1046 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Brad Schick (brad) <brad@robotbattle.com>
   History:   15-Jan-05, brad: split out from image.cpp
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: jpgimage.cpp 994 2006-11-25 15:38:38Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: jpgimage.cpp 1046 2007-02-06 15:00:23Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -176,9 +176,9 @@ namespace Exiv2 {
 
     } // Photoshop::setIptcIrb
 
-    JpegBase::JpegBase(BasicIo::AutoPtr io, bool create,
+    JpegBase::JpegBase(int type, BasicIo::AutoPtr io, bool create,
                        const byte initData[], long dataSize)
-        : Image(mdExif | mdIptc | mdComment), io_(io)
+        : Image(type, mdExif | mdIptc | mdComment, io)
     {
         if (create) {
             initImage(initData, dataSize);
@@ -197,57 +197,6 @@ namespace Exiv2 {
         return 0;
     }
 
-    bool JpegBase::good() const
-    {
-        if (io_->open() != 0) return false;
-        IoCloser closer(*io_);
-        return isThisType(*io_, false);
-    }
-
-    void JpegBase::clearMetadata()
-    {
-        clearIptcData();
-        clearExifData();
-        clearComment();
-    }
-
-    void JpegBase::clearIptcData()
-    {
-        iptcData_.clear();
-    }
-
-    void JpegBase::clearExifData()
-    {
-        exifData_.clear();
-    }
-
-    void JpegBase::clearComment()
-    {
-        comment_.erase();
-    }
-
-    void JpegBase::setExifData(const ExifData& exifData)
-    {
-        exifData_ = exifData;
-    }
-
-    void JpegBase::setIptcData(const IptcData& iptcData)
-    {
-        iptcData_ = iptcData;
-    }
-
-    void JpegBase::setComment(const std::string& comment)
-    {
-        comment_ = comment;
-    }
-
-    void JpegBase::setMetadata(const Image& image)
-    {
-        setIptcData(image.iptcData());
-        setExifData(image.exifData());
-        setComment(image.comment());
-    }
-
     int JpegBase::advanceToMarker() const
     {
         int c = -1;
@@ -265,9 +214,7 @@ namespace Exiv2 {
 
     void JpegBase::readMetadata()
     {
-        if (io_->open() != 0) {
-            throw Error(9, io_->path(), strError());
-        }
+        if (io_->open() != 0) throw Error(9, io_->path(), strError());
         IoCloser closer(*io_);
         // Ensure that this is the correct image type
         if (!isThisType(*io_, true)) {
@@ -577,7 +524,7 @@ namespace Exiv2 {
         0x11,0x03,0x11,0x00,0x3F,0x00,0xA0,0x00,0x0F,0xFF,0xD9 };
 
     JpegImage::JpegImage(BasicIo::AutoPtr io, bool create)
-        : JpegBase(io, create, blank_, sizeof(blank_))
+        : JpegBase(ImageType::jpeg, io, create, blank_, sizeof(blank_))
     {
     }
 
@@ -613,7 +560,7 @@ namespace Exiv2 {
         iIo.read(tmpBuf, 2);
         if (iIo.error() || iIo.eof()) return false;
 
-        if (0xff!=tmpBuf[0] || JpegImage::soi_!=tmpBuf[1]) {
+        if (0xff != tmpBuf[0] || JpegImage::soi_ != tmpBuf[1]) {
             result = false;
         }
         if (!advance || !result ) iIo.seek(-2, BasicIo::cur);
@@ -624,7 +571,7 @@ namespace Exiv2 {
     const byte ExvImage::blank_[] = { 0xff,0x01,'E','x','i','v','2',0xff,0xd9 };
 
     ExvImage::ExvImage(BasicIo::AutoPtr io, bool create)
-        : JpegBase(io, create, blank_, sizeof(blank_))
+        : JpegBase(ImageType::exv, io, create, blank_, sizeof(blank_))
     {
     }
 
