@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2006-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -57,63 +57,28 @@ EXIV2_RCSID("@(#) $Id: pngimage.cpp 823 2006-06-12 07:35:00Z cgilles $")
 // class member definitions
 namespace Exiv2 {
 
-    PngImage::PngImage(BasicIo::AutoPtr io, bool create)
-        : Image(mdExif | mdIptc), io_(io)
+    PngImage::PngImage(BasicIo::AutoPtr io, bool /*create*/)
+        : Image(ImageType::png, mdExif | mdIptc, io)
     {
-        if (create) 
-        {
-            IoCloser closer(*io_);
-            io_->open();
-        }
     } // PngImage::PngImage
 
-    bool PngImage::good() const
+    void PngImage::setExifData(const ExifData& /*exifData*/)
     {
-        if (io_->open() != 0) return false;
-        IoCloser closer(*io_);
-        return isThisType(*io_, false);
+        // Todo: implement me!
+        throw(Error(32, "Exif metadata", "PNG"));
     }
 
-    void PngImage::clearMetadata()
+    void PngImage::setIptcData(const IptcData& /*iptcData*/)
     {
-        clearExifData();
-    }
-
-    void PngImage::setMetadata(const Image& image)
-    {
-        setExifData(image.exifData());
-    }
-
-    void PngImage::clearExifData()
-    {
-        exifData_.clear();
-    }
-
-    void PngImage::setExifData(const ExifData& exifData)
-    {
-        exifData_ = exifData;
-    }
-
-    void PngImage::clearIptcData()
-    {
-        iptcData_.clear();
-    }
-
-    void PngImage::setIptcData(const IptcData& iptcData)
-    {
-        iptcData_ = iptcData;
-    }
-
-    void PngImage::clearComment()
-    {
-        // not yet supported.
-        // TODO : Add 'iTXt' chunk 'Description' tag support here
+        // Todo: implement me!
+        throw(Error(32, "IPTC metadata", "PNG"));
     }
 
     void PngImage::setComment(const std::string& /*comment*/)
     {
-        // not yet supported
-        // TODO : Add 'iTXt' chunk 'Description' tag support here
+        // Todo: implement me!
+        // Add 'iTXt' chunk 'Description' tag support here
+        throw(Error(32, "Image comment", "PNG"));
     }
 
     void PngImage::readMetadata()
@@ -121,13 +86,13 @@ namespace Exiv2 {
 #ifdef DEBUG
         std::cerr << "Exiv2::PngImage::readMetadata: Reading PNG file " << io_->path() << "\n";
 #endif
-        if (io_->open() != 0) 
+        if (io_->open() != 0)
         {
             throw Error(9, io_->path(), strError());
         }
         IoCloser closer(*io_);
         // Ensure that this is the correct image type
-        if (!isThisType(*io_, false)) 
+        if (!isPngType(*io_, false))
         {
             if (io_->error() || io_->eof()) throw Error(14);
             throw Error(3, "PNG");
@@ -142,8 +107,8 @@ namespace Exiv2 {
             makes decisions what to do. It reads only one chunk at a time
             instead of the whole file.
 
-          - new class PngChunk, initialized with the memory of one chunk and 
-            has all the access methods required to determine the field, key, 
+          - new class PngChunk, initialized with the memory of one chunk and
+            has all the access methods required to determine the field, key,
             to access and decompress data etc.
         */
 
@@ -151,23 +116,16 @@ namespace Exiv2 {
 
     void PngImage::writeMetadata()
     {
-    /*
-       TODO: implement me!
-    */
+        //! Todo: implement me!
+        throw(Error(31, "PNG"));
     } // PngImage::writeMetadata
 
-    bool PngImage::isThisType(BasicIo& iIo, bool advance) const
-    {
-        return isPngType(iIo, advance);
-    }
-
     // *************************************************************************
     // free functions
-
     Image::AutoPtr newPngInstance(BasicIo::AutoPtr io, bool create)
     {
         Image::AutoPtr image(new PngImage(io, create));
-        if (!image->good()) 
+        if (!image->good())
         {
             image.reset();
         }
@@ -177,15 +135,15 @@ namespace Exiv2 {
     bool isPngType(BasicIo& iIo, bool advance)
     {
         const int32_t len = 8;
-        const unsigned char pngID[8] = { 0x89, 0x50, 0x4E, 0x47, 0x0D, 0x0A, 0x1A, 0x0A };
+        const unsigned char pngId[8] = { 0x89, 0x50, 0x4E, 0x47, 0x0D, 0x0A, 0x1A, 0x0A };
         byte buf[len];
         iIo.read(buf, len);
-        if (iIo.error() || iIo.eof()) 
+        if (iIo.error() || iIo.eof())
         {
             return false;
         }
-        int rc = memcmp(buf, pngID, 8);
-        if (!advance || rc != 0) 
+        int rc = memcmp(buf, pngId, 8);
+        if (!advance || rc != 0)
         {
             iIo.seek(-len, BasicIo::cur);
         }
