@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2006-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -21,7 +21,7 @@
 /*!
   @file    tiffvisitor.hpp
   @brief   Operations on a TIFF composite tree, implemented as visitor classes.
-  @version $Rev: 837 $
+  @version $Rev: 1040 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    11-Apr-06, ahu: created
@@ -244,13 +244,26 @@ namespace Exiv2 {
         void decodeOlympThumb(const TiffEntryBase* object);
         //! Decode SubIFD contents to Image group if it contains primary image data
         void decodeSubIfd(const TiffEntryBase* object);
-        //! Decode IPTC data from a Photoshop IRB tag
-        void decodeIrbIptc(const TiffEntryBase* object);
+        //! Decode IPTC data from an IPTCNAA tag or Photoshop ImageResources
+        void decodeIptc(const TiffEntryBase* object);
         //@}
 
     private:
         //! Set an Exif tag in the image. Overwrites existing tags
         void setExifTag(const ExifKey& key, const Value* pValue);
+        /*!
+          @brief Get the data for a \em tag and \em group, either from the
+                 \em object provided, if it matches or from the matching element
+                 in the hierarchy.
+
+          Populates \em pData and \em size with the result. If no matching
+          element is found the function leaves both of these parameters unchanged.
+        */
+        void getObjData(byte const*&         pData,
+                        long&                size,
+                        uint16_t             tag,
+                        uint16_t             group,
+                        const TiffEntryBase* object);
 
         // DATA
         Image* pImage_;              //!< Pointer to the image to which the metadata is added
@@ -263,6 +276,7 @@ namespace Exiv2 {
         typedef std::map<uint16_t, uint32_t> GroupType;
         GroupType groupType_;        //!< NewSubfileType for each group
 
+        bool decodedIptc_;           //!< Indicates if IPTC has been decoded yet
     }; // class TiffMetadataDecoder
 
     /*!
@@ -389,7 +403,7 @@ namespace Exiv2 {
         //! Return the base offset. See class TiffRwState for details
         uint32_t baseOffset() const;
         //! Create a TIFF component for \em extendedTag and group
-        std::auto_ptr<TiffComponent> create(uint32_t extendedTag, 
+        std::auto_ptr<TiffComponent> create(uint32_t extendedTag,
                                             uint16_t group) const;
         //@}
 
