@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -21,7 +21,7 @@
 /*!
   @file    types.hpp
   @brief   Type definitions for %Exiv2 and related functionality
-  @version $Rev: 866 $
+  @version $Rev: 1039 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    09-Jan-04, ahu: created<BR>
@@ -92,6 +92,9 @@ namespace Exiv2 {
     //! An identifier for each type of metadata
     enum MetadataId { mdExif=1, mdIptc=2, mdComment=4 };
 
+    //! An identifier for each mode of metadata support
+    enum AccessMode { amNone=0, amRead=1, amWrite=2, amReadWrite=3 };
+
     //! Type identifiers for IFD format types
     enum TypeId { invalidTypeId, unsignedByte, asciiString, unsignedShort,
                   unsignedLong, unsignedRational, invalid6, undefined,
@@ -311,6 +314,12 @@ namespace Exiv2 {
      */
     int exifTime(const char* buf, struct tm* tm);
 
+    /*!
+      @brief Translate a string using the gettext framework. This wrapper hides
+             all the implementation details from the interface.
+     */
+    const char* exvGettext(const char* str);
+
 // *****************************************************************************
 // template and inline definitions
 
